@@ -310,7 +310,8 @@ class Variable(VariableInterface):
             if commentVal:
                 valDict = dict(zip(choiceVal, commentVal))
                 if "list" in self.type:
-                    return map(lambda x: valDict.get(x, x), val)
+                    return [x if isinstance(x, (list, tuple))
+                            else valDict.get(x, x) for x in val]
                 else:
                     return valDict.get(val, val)
         return val
